# autodiffpy

[![Build Status](https://travis-ci.org/rajayuco/cs207-FinalProject.svg?branch=master)](https://travis-ci.org/rajayuco/cs207-FinalProject.svg?branch=master))

[![Coverage Status](https://coveralls.io/repos/github/rajayuco/cs207-FinalProject/badge.svg?branch=master)](https://coveralls.io/github/rajayuco/cs207-FinalProject?branch=master)

* Group name: rajayuco
* Group number: 6
* Team members: Rachel Moon, Jamila Pegues, Yudi Wang, Cory Williams

Welcome! Thank you for downloading our autodiffpy package. 

Details of our package can be found at: https://github.com/rajayuco/cs207-FinalProject/blob/master/docs/documentation.ipynb

Enjoy autodiffing! :D
